/*
 * The MIT License
 *
 * Copyright 2020 Charles University
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package cz.cuni.mff.java.cv07plus;

import java.io.IOException;
import java.nio.file.*;
import static java.nio.file.StandardWatchEventKinds.*;

public class DirMonitor {
    public static void main(String[] args) {
        if (args.length != 1) {
            System.out.println("Exactly one argument required.");
            System.exit(1);
        }
        Path dir = Path.of(args[0]);
        if (!Files.isDirectory(dir)) {
            System.out.println("Given argument is not a directory");
            System.exit(1);
        }
        try {
            WatchService watchService = FileSystems.getDefault().newWatchService();
            WatchKey key = dir.register(watchService, ENTRY_CREATE, ENTRY_DELETE, ENTRY_MODIFY);
            while (true) {
                for (WatchEvent<?> l : key.pollEvents()) {
                    Path p = (Path) l.context();
                    if (p != null) {
                        WatchEvent.Kind<?> kind = l.kind();
                        if (kind.equals(ENTRY_CREATE)) {
                            System.out.println("New element added to the directory\n  " + p);
                        } else if (kind.equals(ENTRY_DELETE)) {
                            System.out.println("An element deleted from the directory\n  " + p);
                        } else if (kind.equals(ENTRY_MODIFY)) {
                            System.out.println("An element modified in the directory\n  " + p);
                        }
                    }
                }
            }
        } catch (IOException ex) {
            System.out.println("IOException occurred");
            System.exit(1);
        }
    }
}
